AQA Biology Paper 1 - 121 Quick-Fire Questions. Revision for 9-1 GCSE Combined Science or Biology

Science and Maths by Primrose Kitten

AQA Biology Paper 1 - 121 Quick-Fire Questions. Revision for 9-1 GCSE Combined Science or Biology

I want to help you achieve the grades you (and I) know you are capable of; these grades are the stepping stone to your future. Even if you don't want to study science or maths further, the grades you get now will open doors in the future.
To help you get even better grades I’ve written a lot of e-books, packed full of loads of awesome questions to help you study. Because the best thing you can to is practice. Visit my website for e-books, flashcards and extension questions https://www.primrosekitten.com/collections/gcse If you want more than one thing you should consider the Science or Math discount bundles and save yourself some money
https://www.primrosekitten.com/collections/gcse/products/gcse-science-discount-bundle
https://www.primrosekitten.com/collections/gcse/products/gcse-maths-discount-bundle
GCSE Maths in only 2 hours https://youtu.be/dYPwEyeyPLA (All exam boards)
AQA Chemistry paper 1 https://youtu.be/MpQ-3YAwNhI
AQA Chemistry paper 2 https://youtu.be/_HJu8WTtZJU
AQA Physics Paper 1 https://youtu.be/xtw-Z0nllA4
AQA Physics Paper 2 https://youtu.be/X1aMXCr75Kw
AQA Biology Paper 1 https://youtu.be/mKYQ-K23Mr4
AQA Biology Paper 2 https://youtu.be/Uqti-xPnT-8
Edexcel Chemistry paper 1 https://youtu.be/5inBtFdZa7A
Edexcel Chemistry paper 2 https://youtu.be/woYFftjEkeM
Edexcel Physics Paper 1 https://youtu.be/4GxHd7ATpao
Edexcel Physics Paper 2 https://youtu.be/VY-I7aeHXOI
Edexcel Biology Paper 1 https://youtu.be/O_a9BRQbVc0
Edexcel Biology Paper 2 https://youtu.be/L6ODraBBZRg
TuitionKit allows you to schedule your revision videos, mine and loads of other great YouTubers! http://bit.ly/2yYIxxG
My exam predictions are just GUESSES!! I don't have any insider knowledge just years of looking at exam papers. Use this as a starting point, but revise EVERYTHING fully. The best way to revise is to get your hands on the past papers and marks schemes (freely available on the exam board website) and look at what questions have been asked and how to answer them. I have lots of notes and exam papers on here to help you.
Disclaimer; You should not carry out any of these practical’s without carrying out a full risk assessment of your own first. Just watching these video will not guarantee to get you a good grade, you’ll also need hard work, this is not a quick fix. I am human and I make mistakes, please point out any that you find and there is no need to follow that with a load of abuse.
Some of the links in here are affiliate links, where is get a small percentage of any money spent, if you like my channel and want to support my work, clicking these is an easy way to do it.
The 'whole of topic in xxx minutes' videos DO NOT comprehensively cover everything you need to know for your exams. it would be impossible to cover 2 years of teaching in under 45 minutes. These should NOT be your only source of revision https://youtu.be/K6d4oOq-pmU xoxox
PhET Interactive Simulations
University of Colorado Boulder
https://phet.colorado.edu
Music; Something Elated by Broke For Free. From the Free Music Archive, CC BY
Images from; Classroom Core (TpT), Hidesy Clipart (TpT), The Cher Room (TpT), The Triple Point (TpT), Ninja Woman (TpT), The Painted Crew (TpT) Teacher's Clipart (TpT) Shutterstock

13/04/2018